``broken_barh()`` vertical alignment though ``align`` parameter
---------------------------------------------------------------
`~.Axes.broken_barh` now supports vertical alignment of the bars through the
``align`` parameter.
